### Парсер Русского Викисловаря
Небольшой модуль, который позволяет получить морфологические свойства, значения, синонимы и антонимы слов с https://ru.wiktionary.org/
#### Пример респонса для слова "любовь"
```json
{
   "morphology":"Существительное, неодушевлённое, женский род, 3-е склонение тип склонения 8 по классификации А.А.Зализняка.",
   "definitions":[
      {
         "value":"чувство глубокой привязанности к кому-либо, чему-либо",
         "example":"Материнская любовь."
      },
      {
         "value":"чувство расположения, симпатии к кому-либо",
         "example":"Хитрым и вкрадчивым умом умела она приобрести любовь своих господ. А.С.Пушкин, Арап Петра Великого, г. МАС"
      },
      {
         "value":"чувство горячей сердечной склонности, влечение к другому человеку",
         "example":"Жениться по любви."
      },
      {
         "value":"чья-то о человеке, внушающем чувство любви в предыдущем значении",
         "example":"Прощай, мать, прощай, моя невеста, моя любовь! В.М.Гаршин, Четыре дня, г. МАС"
      },
      {
         "value":"любовные отношения",
         "example":"Несколько лет провела бабушка на виноделии в Кизляре. Там-то она и прижила в тайной любви мою мать  Настю.  Ф.В.Гладков, Повесть о детстве, г. МАС"
      },
      {
         "value":"внутреннее стремление, влечение, склонность, тяготение к чему-либо",
         "example":"Любовь к свободе родины у Инсарова  во всём организме, и что бы ни вошло в него, всё претворяется силою этого чувства.  Н.А.Добролюбов, Когда же придёт настоящий день, г. МАС"
      },
      {
         "value":"пристрастие к чему-либо, предпочтение чего-либо",
         "example":"Любовь к приключениям."
      }
   ],
   "synonyms":[
      "привязанность",
      "приязнь, симпатия",
      "эрос",
      "любимый, возлюбленный, люба, лада",
      "роман",
      "склонность",
      "пристрастие"
   ],
   "antonyms":[
      "ненависть, вражда",
      "неприязнь, отвращение, антипатия, нелюбовь"
   ]
}
```
#### Пример использования
```python
from wiktionaryparserru.parser import WiktionaryParser

word = input()
parser = WiktionaryParser()
parsed_response = parser.make_request(word)
print(parsed_response)
```